@@ -1,4 +1,6 @@
 package XML::Loy::Atom::Threading;
+use strict;
+use warnings;
 
 our $PREFIX;
 BEGIN { $PREFIX = 'thr' };
@@ -261,7 +263,7 @@ L<Mojolicious>.
 
 =head1 COPYRIGHT AND LICENSE
 
-Copyright (C) 2011-2015, L<Nils Diewald|http://nils-diewald.de/>.
+Copyright (C) 2011-2016, L<Nils Diewald|http://nils-diewald.de/>.
 
 This program is free software, you can redistribute it
 and/or modify it under the same terms as Perl.
