@@ -1,4 +1,6 @@
 package XML::Loy::GeoRSS;
+use strict;
+use warnings;
 
 use XML::Loy with => (
   prefix => 'georss',
@@ -359,7 +361,7 @@ L<Mojolicious>.
 
 =head1 COPYRIGHT AND LICENSE
 
-Copyright (C) 2011-2015, Nils Diewald.
+Copyright (C) 2011-2016, Nils Diewald.
 
 This program is free software, you can redistribute it
 and/or modify it under the same terms as Perl.
