@@ -1,4 +1,7 @@
 package XML::Loy::HostMeta;
+use strict;
+use warnings;
+
 use XML::Loy with => (
   prefix => 'hm',
   namespace => 'http://host-meta.net/xrd/1.0'
@@ -96,7 +99,7 @@ L<Mojolicious>.
 
 =head1 COPYRIGHT AND LICENSE
 
-Copyright (C) 2011-2015, L<Nils Diewald|http://nils-diewald.de/>.
+Copyright (C) 2011-2016, L<Nils Diewald|http://nils-diewald.de/>.
 
 This program is free software, you can redistribute it
 and/or modify it under the same terms as Perl.
